from rocolib.api.components import FoldedComponent
from rocolib.api.composables.graph.Face import Face, Rectangle, RegularNGon
from rocolib.api.composables.graph.Face import RegularNGon2 as r2l
from rocolib.utils.numsym import sin, deg2rad


class Stool(FoldedComponent):
    def define(self):
        self.addParameter("height", 60, paramType="length", minValue=10)
        self.addParameter("legs", 3, paramType="count", minValue=1)
        self.addParameter("radius", optional=True, overrides=("legwidth",))
        self.addParameter("legwidth", 20, paramType="length", minValue=10)
        self.addParameter("angle", 80, paramType="angle")

    def modifyParameters(self):
        if self.getParameter("radius") is not None:
          self.setParameter("legwidth", r2l.r2l(self.getParameter("radius"), self.getParameter("legs")*2))

    def assemble(self):
        h = self.getParameter("height")
        lp = self.getParameter("legs")
        e = self.getParameter("legwidth")
        ap = self.getParameter("angle")

        n = lp * 2
        self.addFace(RegularNGon("", n, e), "seat")

        for i in range(0, int(n/2)):
            s = Rectangle("", e, h)
            self.attachEdge("seat.e%d" % (2*i), s, "e0", "leg%d" % i, angle=ap)

if __name__ == "__main__":
    from rocolib.api.composables.graph.Joint import FingerJoint
    Stool.test(thickness=4, joint=FingerJoint(thickness=4))

